# Chapter 9: Fund Investment and Asset Allocation Theory

This chapter is currently maintained in Chinese first.

- Chinese chapter: [第 9 章：基金投资与资产配置理论](../../zh/textbook/09_funds.md)
- Textbook home: [Chinese textbook index](../../zh/textbook/index.md)
- Practice links:
  - Primary example: [examples/textbook/ch09_funds.py](https://github.com/akfamily/akquant/blob/main/examples/textbook/ch09_funds.py)
  - Extended example: [examples/textbook/ch09_portfolio.py](https://github.com/akfamily/akquant/blob/main/examples/textbook/ch09_portfolio.py)
  - Guide: [Strategy Guide](../guide/strategy.md)
